@@ -56,6 +56,12 @@ KILOWATTHOURS = 'kWh'
 
 BAR = 'bar'
 
+RPM = 'U/min'
+
+FLOW = 'l/min'
+
+FREQUENCY = 'Hz'
+
 CELSIUS_TEMPERATURE = '°C'
 
 VALUES = 'Values'
